
# Slot: edge_list_numeric_edge_type_ids


Whether to load the edge type IDs as numeric from the edge list.

URI: [https://w3id.org/neat/ensmallenRunConfig__edge_list_numeric_edge_type_ids](https://w3id.org/neat/ensmallenRunConfig__edge_list_numeric_edge_type_ids)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
